//biblioteka obsugi ukadu TC77 - termometru cyfrowego dziaajcego na SPI
//autor: Mariusz Dziebowski
//data: 10.02.2011

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_conf.h"
#include "lib_tc77.h"

/* Private functions ---------------------------------------------------------*/

void TC77_Init(void)
{
	SPI_InitTypeDef SPI_InitStructure;
	GPIO_InitTypeDef GPIO_InitStructure;

	//wczenie zegarw wykorzystywanych peryferii
	TC77_RCC_APBPeriphCmd_SPI(TC77_RCC_APBPeriph_SPI, ENABLE);
	TC77_RCC_APBPeriphCmd_Port(TC77_RCC_APBPeriph_Port, ENABLE);

	//inicjalizacja pinow transmisji SPI
	//SCK, MOSI
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
	GPIO_InitStructure.GPIO_Pin = TC77_SCK | TC77_SIO;
	GPIO_Init(GPIOA, &GPIO_InitStructure);
	//CS
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	GPIO_InitStructure.GPIO_Pin = TC77_CS;
	GPIO_Init(GPIOA, &GPIO_InitStructure);

	//ustawienie linii CS - stan wysoki
	Deselect_TC77;

	//konfiguracja SPI
	SPI_InitStructure.SPI_Direction = SPI_Direction_1Line_Rx;
	SPI_InitStructure.SPI_Mode = SPI_Mode_Master;
	SPI_InitStructure.SPI_DataSize = SPI_DataSize_16b;
	SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low;
	SPI_InitStructure.SPI_CPHA = SPI_CPHA_1Edge;
	SPI_InitStructure.SPI_NSS = SPI_NSS_Soft;
	SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_256;
	SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;
	SPI_InitStructure.SPI_CRCPolynomial = 7;

	//inicjalizacja SPI
	SPI_Init(TC77_SPI, &SPI_InitStructure);
}

uint16_t TC77_GetTemp(void)
{
	uint16_t temp = 0;

	//ustawienie linii - stan niski
	Select_TC77;
	//wlaczenie spi
	SPI1->CR1 |= SPI_CR1_SPE;

	//oczekiwanie na zakoczenie odbiodu danych
	while (((SPI1->SR & SPI_I2S_FLAG_RXNE) == (uint16_t)RESET)){};
	//odczyt odebranych danych
	temp = SPI1->DR;

	//wyczenie SPI
	SPI1->CR1 &= ~SPI_CR1_SPE;
	//ustawienie linii - stan wysoki
	Deselect_TC77;

	return temp;
}

uint16_t TC77_GetID(void)
{
	uint16_t temp = 0;

	//ustawienie linii - stan niski
	Select_TC77;
	//wlaczenie spi
	SPI1->CR1 |= SPI_CR1_SPE;

	//oczekiwanie na zakoczenie odbiodu danych
	while (((SPI1->SR & SPI_I2S_FLAG_RXNE) == (uint16_t)RESET)){};
	//odczyt odebranych danych
	SPI1->DR;

	//ustawienie na wysyanie
	SPI1->CR1 |= SPI_CR1_BIDIOE;

	//wysnie danych
	SPI1->DR = 0xFFFF;
	//oczekiwanie na zakoczenie pracy SPI
	while (((SPI1->SR & SPI_I2S_FLAG_BSY) != (uint16_t)RESET)){};

	//przeczenie odbior
	SPI1->CR1 &= ~SPI_CR1_BIDIOE;

	//oczekiwanie na zakoczenie odbiodu danych
	while (((SPI1->SR & SPI_I2S_FLAG_RXNE) == (uint16_t)RESET)){};
	//odczyt odebranych danych
	temp = SPI1->DR;

	//przeczenie w tryb wysyania
	SPI1->CR1 |= SPI_CR1_BIDIOE;

	//wysnie danych
	SPI1->DR = 0x0000;
	//oczekiwanie na zakoczenie pracy SPI
	while (((SPI1->SR & SPI_I2S_FLAG_BSY) != (uint16_t)RESET)){};

	//wyczenie SPI
	SPI1->CR1 &= ~SPI_CR1_SPE;
	//przeczenie w tryb odbioru
	SPI1->CR1 &= ~SPI_CR1_BIDIOE;
	//ustawienie linii - stan wysoki
	Deselect_TC77;

	return temp;
}
