/**
*****************************************************************************
**
**  File        : main.c
**
**  Abstract    : main function.
**
**  Functions   : main
**
*****************************************************************************
*/

/* Includes */
#include <stddef.h>
#include "stm32f10x.h"
#include "lib_pcd8544.h"
#include "lib_tc77.h"

/* Private typedef */
/* Private define  */
/* Private macro */


/* Private variables */
uint32_t freq = 0;						//zmienna przechowuje czestotliwosc taktowania rdzenia mikrokontrolera
uint32_t temp_tc77;
uint16_t id_tc77;

/* Private function prototypes */
/* Private functions */
void Configuration_RCC(void);
void Configuration_Interrupts(void);

/**
**===========================================================================
**
**  Abstract: main program
**
**===========================================================================
*/
int main(void)
{
	//konfiguracja RCC
	Configuration_RCC();
	//inicjalizacja TC77
	TC77_Init();

	//pobranie id ukdu TC77
	id_tc77 = TC77_GetID();

	//konfiguracja przerwania SysTcik
	Configuration_Interrupts();

	//inicjalizacja i obsuga wywietlacza
	PCD8544_INIT();
	PCD8544_LCDClear();
	PCD8544_LCDWriteText("Pomiar temp.", 6, 1);

	//zapisanie ID na wywietlacz
	PCD8544_LCDWriteText("TC77 ID:", 3, 4);
	PCD8544_LCDWriteSign('0', 57, 4);
	PCD8544_LCDWriteSign('x', 63, 4);
	PCD8544_LCDWriteSign(id_tc77 / 0x1000 + 0x30, 69, 4);
	PCD8544_LCDWriteSign(id_tc77 % 0x1000 / 0x0100 + 0x30, 75, 4);

	while (1){}
}

void Configuration_RCC(void)
{
	ErrorStatus HSEStartUpStatus;

	//Reset ustawien RCC
	RCC_DeInit();

	//Wlaczaenie HSE
	RCC_HSEConfig(RCC_HSE_ON);

	//Zaczekaj az HSE zostaeni zainicjowany
	HSEStartUpStatus = RCC_WaitForHSEStartUp();

	//jesli HSE zosta zainicjalizowany poprawnie
	if(HSEStartUpStatus == SUCCESS)
	{
		//Opoznienie dla pamieci Flash
		FLASH_SetLatency(FLASH_Latency_2);

		//Wlaczenie buffora pamieci flash
		FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);

		//konfiguracja preskalera AHB
		//HCLK = SYSCLK
		RCC_HCLKConfig(RCC_SYSCLK_Div1);

		//konfigracja preskalera APB2
	    //PCLK2 = HCLK = 72MHz, czestotliwosz 72MHz bedzie uzyskana dopiero po pelnej inicjalizacji RCC
		RCC_PCLK2Config(RCC_HCLK_Div1);

	    //konfigracja preskalera APB1
		//PCLK1 = HCLK/2 = 36MHz, czestotliwosz 36MHz bedzie uzyskana dopiero po pelnej inicjalizacji RCC
		RCC_PCLK1Config(RCC_HCLK_Div2);

	    //konfiguracja PLLLCK
		//PLLCLK = HSE / 1 * 9 = 72 MHz
		RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);

		//Enable PLL
	    RCC_PLLCmd(ENABLE);

	    //odczekanie az PLL bedzie gotowy do pracy
	    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET){}

	    //konfiguracja SW
		//wybranie PLL jako SYSCLK
		RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);

	    //odczekanie az PLLCLK bedzie sygnaem zegarowym mikrokontrolera
	    while((RCC->CFGR & (uint32_t)RCC_CFGR_SWS) != (uint32_t)0x08){}
	}

	//wczenie zegarw wykorzystywanych peryferii APB1
	RCC_APB1PeriphClockCmd(
		RCC_APB1Periph_BKP | //wlaczenie zegara dla funkcji podtrzymania pamieci
		RCC_APB1Periph_PWR   //wlaczenie zegara dla funkcji power
		, ENABLE);
}

void Configuration_Interrupts(void)
{
	//zdefiniowanie struktury wykorzystywanej do konfiguracji przerwani
	NVIC_InitTypeDef NVIC_InitStructure;
	RCC_ClocksTypeDef RCC_Clocks;

	//skonfigurowanie miejsca przechowywania tablicy wektorow przerwan
	NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);

	//konfiguracja podzialu priorytetow przerwan: 4 grupy, 4 podgrupy
	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_2);

	//konfiguracja przerwan pochodzacych od SysTick
	NVIC_InitStructure.NVIC_IRQChannel = SysTick_IRQn;
	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 2;
	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
	NVIC_Init(&NVIC_InitStructure);

	//uzyskanie czestotliwosci poszczegolnych linii zegara
	RCC_GetClocksFreq(&RCC_Clocks);

	//ustawienie przerwania SysTick
	SysTick_Config(RCC_Clocks.SYSCLK_Frequency / 10);

	freq = RCC_Clocks.SYSCLK_Frequency;
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/*
 * Minimal __assert_func used by the assert() macro
 * */
void __assert_func(const char *file, int line, const char *func, const char *failedexpr)
{
  while(1)
  {}
}

/*
 * Minimal __assert() uses __assert__func()
 * */
void __assert(const char *file, int line, const char *failedexpr)
{
   __assert_func (file, line, NULL, failedexpr);
}

#ifdef USE_SEE
#ifndef USE_DEFAULT_TIMEOUT_CALLBACK
/**
  * @brief  Basic management of the timeout situation.
  * @param  None.
  * @retval sEE_FAIL.
  */
uint32_t sEE_TIMEOUT_UserCallback(void)
{
  /* Return with error code */
  return sEE_FAIL;
}
#endif
#endif /* USE_SEE */

